@@ -1,16 +1,14 @@
 import logging
 
-from ninja_extra import ControllerBase
-
-from easy.controller.meta import CrudAPI, CrudApiMetaclass
+from easy.controller.meta import CrudApiMetaclass
 
 logger = logging.getLogger(__name__)
 
 
-class CrudAPIController(ControllerBase, CrudAPI, metaclass=CrudApiMetaclass):
+class CrudAPIController(metaclass=CrudApiMetaclass):
     """
     Base APIController for auto creating CRUD APIs, configurable via Meta class
-    APIs auto genrated:
+    APIs auto generated:
         Creat
             PUT /{id}       - Create a single Object
 
