@@ -52,6 +52,42 @@ class CrudAPI(CrudModel):
             self.service = BaseService(model=self.model)
         super().__init__(model=self.model)
 
+    # Define Controller APIs for auto generation
+    async def get_obj(self, request: HttpRequest, id: int) -> Any:
+        """
+        GET /{id}
+        Retrieve a single Object
+        """
+        try:
+            qs = await self.service.get_obj(id)
+        except Exception as e:  # pragma: no cover
+            logger.error(f"Get Error - {e}", exc_info=True)
+            return BaseApiResponse(str(e), message="Get Failed", errno=500)
+        if qs:
+            return qs
+        else:
+            return BaseApiResponse(message="Not Found", errno=404)
+
+    async def del_obj(self, request: HttpRequest, id: int) -> Any:
+        """
+        DELETE /{id}
+        Delete a single Object
+        """
+        if await self.service.del_obj(id):
+            return BaseApiResponse("Deleted.", errno=204)
+        else:
+            return BaseApiResponse("Not Found.", errno=404)
+
+    @paginate
+    async def get_objs(self, request: HttpRequest, filters: str = None) -> Any:
+        """
+        GET /?maximum={int}&filters={filters_dict}
+        Retrieve multiple Object (optional: maximum # and filters)
+        """
+        if filters:
+            return await self.service.get_objs(**json.loads(filters))
+        return await self.service.get_objs()
+
 
 class CrudApiMetaclass(ABCMeta):
     def __new__(mcs, name: str, bases: Tuple[Type[Any], ...], attrs: dict) -> Any:
@@ -80,44 +116,6 @@ class CrudApiMetaclass(ABCMeta):
         base_cls_attrs: dict = {}
         base_cls_attrs.update(parent_attrs)
 
-        # Define Controller APIs for auto generation
-        async def get_obj(self, request: HttpRequest, id: int) -> Any:  # type: ignore
-            """
-            GET /{id}
-            Retrieve a single Object
-            """
-            try:
-                qs = await self.service.get_obj(id)
-            except Exception as e:  # pragma: no cover
-                logger.error(f"Get Error - {e}", exc_info=True)
-                return BaseApiResponse(str(e), message="Get Failed", errno=500)
-            if qs:
-                return qs
-            else:
-                return BaseApiResponse(message="Not Found", errno=404)
-
-        async def del_obj(self, request: HttpRequest, id: int) -> Any:  # type: ignore
-            """
-            DELETE /{id}
-            Delete a single Object
-            """
-            if await self.service.del_obj(id):
-                return BaseApiResponse("Deleted.", errno=204)
-            else:
-                return BaseApiResponse("Not Found.", errno=404)
-
-        @paginate
-        async def get_objs(  # type: ignore
-            self, request: HttpRequest, filters: str = None
-        ) -> Any:
-            """
-            GET /?maximum={int}&filters={filters_dict}
-            Retrieve multiple Object (optional: maximum # and filters)
-            """
-            if filters:
-                return await self.service.get_objs(**json.loads(filters))
-            return await self.service.get_objs()
-
         if opts_model:
 
             class DataSchema(ModelSchema):
@@ -160,30 +158,32 @@ class CrudApiMetaclass(ABCMeta):
                 f"{opts_model.__name__}__AutoSchema({str(uuid.uuid4())[:4]})"
             )
 
+            setattr(CrudAPI, "patch_obj", patch_obj)
+            setattr(CrudAPI, "add_obj", add_obj)
+
             base_cls_attrs.update(
                 {
                     "patch_obj_api": http_patch(
                         "/{id}", summary="Patch a single object"
                     )(
-                        copy_func(patch_obj)  # type: ignore
+                        copy_func(CrudAPI.patch_obj)  # type: ignore
                     ),
                     "add_obj_api": http_put("/", summary="Create")(
-                        copy_func(add_obj)  # type: ignore
+                        copy_func(CrudAPI.add_obj)  # type: ignore
                     ),
                 }
             )
 
-        base_cls_attrs.update(parent_attrs)
         base_cls_attrs.update(
             {
                 "get_obj_api": http_get("/{id}", summary="Get a single object")(
-                    copy_func(get_obj)  # type: ignore
+                    copy_func(CrudAPI.get_obj)  # type: ignore
                 ),
                 "del_obj_api": http_delete("/{id}", summary="Delete a single object")(
-                    copy_func(del_obj)  # type: ignore
+                    copy_func(CrudAPI.del_obj)  # type: ignore
                 ),
                 "get_objs_api": http_get("/", summary="Get multiple objects")(
-                    copy_func(get_objs)  # type: ignore
+                    copy_func(CrudAPI.get_objs)  # type: ignore
                 ),
             }
         )
